@@ -27,10 +27,12 @@ def ddprint(a):
 
 #input("DD GUI Library has been installed.")
 
-"""
+
 
 # First Method
 
+"""
+
 class MyForm(QDialog):
 
     def __init__(self):
@@ -50,7 +52,6 @@ if __name__ == "__main__":
 
 """
 
-
 #Second Method
 #app = QApplication(sys.argv)
 #window = QWidget()
@@ -59,7 +60,6 @@ if __name__ == "__main__":
 
 
 
-"""
 # Third Method
 
 class Ui(QDialog):
@@ -67,12 +67,15 @@ class Ui(QDialog):
         super(Ui, self).__init__()
         uic.loadUi('ddgui.ui', self)
 
+        self.pushButtonExit.clicked.connect(self.exitMethod)
+        self.show()
+
         #self.button = self.findChild(QtWidgets.QPushButton, 'printButton') # Find the button
         #self.button.clicked.connect(self.printButtonPressed) # Remember to pass the definition/method, not the return value!
-
         #self.input = self.findChild(QtWidgets.QLineEdit, 'input')
 
-        self.show()
+    def exitMethod(self):
+        QApplication.instance().quit()
 
     #def printButtonPressed(self):
     #    # This is executed when the button is pressed
@@ -82,8 +85,10 @@ app = QtWidgets.QApplication(sys.argv)
 window = Ui()
 app.exec_()
 
-"""
 
+# Forth Method
+
+"""
 class Ui(QtWidgets.QMainWindow):
     def __init__(self):
         super(Ui, self).__init__()
@@ -94,7 +99,7 @@ app = QtWidgets.QApplication(sys.argv)
 window = Ui()
 app.exec_()
 
-
+"""
 
 
 
